==> xvim-6.1-i386-5.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf eview )
( cd usr/bin ; ln -sf vim eview )
( cd usr/bin ; rm -rf evim )
( cd usr/bin ; ln -sf vim evim )
( cd usr/bin ; rm -rf ex )
( cd usr/bin ; ln -sf vim ex )
( cd usr/bin ; rm -rf gview )
( cd usr/bin ; ln -sf vim gview )
( cd usr/bin ; rm -rf gvim )
( cd usr/bin ; ln -sf vim gvim )
( cd usr/bin ; rm -rf gvimdiff )
( cd usr/bin ; ln -sf vim gvimdiff )
( cd usr/bin ; rm -rf rgview )
( cd usr/bin ; ln -sf vim rgview )
( cd usr/bin ; rm -rf rgvim )
( cd usr/bin ; ln -sf vim rgvim )
( cd usr/bin ; rm -rf rview )
( cd usr/bin ; ln -sf vim rview )
( cd usr/bin ; rm -rf rvim )
( cd usr/bin ; ln -sf vim rvim )
( cd usr/bin ; rm -rf view )
( cd usr/bin ; ln -sf vim view )
( cd usr/doc/vim-6.1 ; rm -rf doc )
( cd usr/doc/vim-6.1 ; ln -sf /usr/share/vim/vim61 doc )
( cd usr/man/man1 ; rm -rf eview.1.gz )
( cd usr/man/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/man1 ; rm -rf ex.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/man1 ; rm -rf gview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/man1 ; rm -rf gvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/man1 ; rm -rf rgview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/man1 ; rm -rf rview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/man1 ; rm -rf rvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/man1 ; rm -rf view.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz view.1.gz )

==> xvim-6.2-i486-1.tgz: install/doinst.sh <==
#!/bin/sh
# If there's no vi link, take over:
if [ ! -r usr/bin/vi ]; then
  ( cd usr/bin ; ln -sf vim vi )
fi
( cd usr/bin ; rm -rf ex )
( cd usr/bin ; ln -sf vim ex )
( cd usr/bin ; rm -rf evim )
( cd usr/bin ; ln -sf vim evim )
( cd usr/bin ; rm -rf gvim )
( cd usr/bin ; ln -sf vim gvim )
( cd usr/bin ; rm -rf rvim )
( cd usr/bin ; ln -sf vim rvim )
( cd usr/bin ; rm -rf view )
( cd usr/bin ; ln -sf vim view )
( cd usr/bin ; rm -rf eview )
( cd usr/bin ; ln -sf vim eview )
( cd usr/bin ; rm -rf gview )
( cd usr/bin ; ln -sf vim gview )
( cd usr/bin ; rm -rf rgvim )
( cd usr/bin ; ln -sf vim rgvim )
( cd usr/bin ; rm -rf rview )
( cd usr/bin ; ln -sf vim rview )
( cd usr/bin ; rm -rf rgview )
( cd usr/bin ; ln -sf vim rgview )
( cd usr/bin ; rm -rf vimdiff )
( cd usr/bin ; ln -sf vim vimdiff )
( cd usr/bin ; rm -rf gvimdiff )
( cd usr/bin ; ln -sf vim gvimdiff )
( cd usr/doc/vim-6.2 ; rm -rf doc )
( cd usr/doc/vim-6.2 ; ln -sf /usr/share/vim/vim62 doc )
( cd usr/man/man1 ; rm -rf gvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/man1 ; rm -rf rview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rview.1.gz )
( cd usr/man/man1 ; rm -rf ex.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz ex.1.gz )
( cd usr/man/man1 ; rm -rf view.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz view.1.gz )
( cd usr/man/man1 ; rm -rf rvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rvim.1.gz )
( cd usr/man/man1 ; rm -rf gview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/man1 ; rm -rf rgview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/man1 ; rm -rf eview.1.gz )
( cd usr/man/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rgvim.1.gz )
